"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const utils_1 = require("@morjs/utils");
const path_1 = tslib_1.__importDefault(require("path"));
const scriptTransformer_1 = require("../transformers/scriptTransformer");
const utils_2 = require("../utils");
/**
 * 支持 ts 和 esbuild 两种编译方式
 * 1. 如果没有插件的情况下, 自动使用 esbuild 以构建速度为主
 * 2. 如果有外部插件 或 需求输出 declaration 则使用 ts 编译
 */
async function ScriptLoader(fileContent) {
    const cb = this.async();
    const options = this.getOptions();
    const { userConfig, entryBuilder, runner } = options;
    const entry = entryBuilder.getEntryByFilePath(this.resourcePath);
    let code;
    let sourceMap;
    let transformers;
    const parserInfo = {
        userConfig,
        loaderContext: this,
        fileInfo: {
            path: this.resourcePath,
            content: fileContent,
            extname: entry ? entry.extname : path_1.default.extname(this.resourcePath),
            entryName: entry ? entry.fullEntryName : undefined,
            entryFileType: entry ? entry.entryFileType : undefined,
            entryType: entry ? entry.entryType : utils_1.EntryType.unknown
        }
    };
    // ts 插件支持
    if ((0, utils_2.shouldProcessFileByPlugins)(this.resourcePath, userConfig.processNodeModules, options.processNodeModules) &&
        runner.hooks.scriptParser.isUsed()) {
        transformers = runner.hooks.scriptParser.call({
            before: [],
            after: [],
            afterDeclarations: []
        }, parserInfo);
    }
    try {
        const res = await (0, scriptTransformer_1.scriptTransformer)(fileContent, utils_1.EntryFileType.script, parserInfo, transformers);
        code = res.code;
        sourceMap = res.sourceMap;
    }
    catch (err) {
        const error = new Error(`文件 ${this.resourcePath} 编译失败, 原因: ${(err === null || err === void 0 ? void 0 : err.message) || ''}`);
        error.stack = err.stack;
        return cb(error);
    }
    const res = (0, scriptTransformer_1.generateSourceMap)(sourceMap, code, this.resourcePath, fileContent, this.remainingRequest);
    cb(null, res.code, res.sourceMap);
}
exports.default = ScriptLoader;
//# sourceMappingURL=scriptLoader.js.map